Module utils

Functions

is_essential_dep
Checks if a dependency is considered essential and should not be removed
is_hidden
Checks if a path represents a hidden file or directory
is_std_crate
Checks if a crate name represents a standard library crate