pub struct CrateReference {
pub name: String,
pub features: HashSet<String>,
pub used_in: HashSet<PathBuf>,
}Expand description
A reference to a crate and its usage within the project
Fields
name: StringName of the crate
features: HashSet<String>Set of features used by this crate
used_in: HashSet<PathBuf>Set of file paths where this crate is used
Implementations